@@ -27,7 +27,9 @@
 
 # Make interface to class TableIterProxy available.
 from ._tables import TableIter
-from .table import table;
+
+from .table import table
+
 
 class tableiter(TableIter):
     """The Python interface to Casacore table iterators
@@ -51,23 +53,23 @@ class tableiter(TableIter):
     """
 
     def __init__(self, table, columnnames, order='', sort=True):
-        st = sort;
+        st = sort
         if isinstance(sort, bool):
-            st = 'heapsort';
+            st = 'heapsort'
             if not sort:
                 st = 'nosort'
-        TableIter.__init__ (self, table, columnnames, order, st);
-    
-    def __iter__ (self):
+        TableIter.__init__(self, table, columnnames, order, st)
+
+    def __iter__(self):
         # __iter__ is needed
-        return self;
+        return self
 
-    def next (self):
+    def next(self):
         # next returns a Table object, so turn that into table.
-        return table (self._next(), _oper=3);
-            
-    def reset (self):
-        """Reset the iterator to the beginning."""
-        self._reset();
+        return table(self._next(), _oper=3)
 
-    __next__ = next
\ No newline at end of file
+    def reset(self):
+        """Reset the iterator to the beginning."""
+        self._reset()
+
+    __next__ = next
